@@ -23,6 +23,7 @@
 
 #include <QDate>
 #include <QDateTime>
+#include <QDir>
 #include <QLatin1Char>
 #include <QLocale>
 #include <QString>
@@ -117,11 +118,12 @@ QString Kwave::ms2hms(double ms)
 
     return i18nc(
 	"time of label tooltip, %1=hour, %2=minute, %3=second, %4=milliseconds",
-	"%1:%2:%3.%4").
-	arg(  h, 2, 10, QLatin1Char('0')).
-	arg(  m, 2, 10, QLatin1Char('0')).
-	arg(  s, 2, 10, QLatin1Char('0')).
-	arg(tms, 4, 10, QLatin1Char('0'));
+	"%1:%2:%3.%4",
+	QString::asprintf("%02u", h),
+	QString::asprintf("%02u", m),
+	QString::asprintf("%02u", s),
+	QString::asprintf("%04u", tms)
+    );
 }
 
 //***************************************************************************
@@ -175,6 +177,13 @@ QString Kwave::string2date(const QString &str)
     return QString();
 }
 
+//***************************************************************************
+QUrl Kwave::URLfromUserInput(const QString &path)
+{
+    return QUrl::fromUserInput(path, QDir::currentPath(),
+                               QUrl::AssumeLocalFile);
+}
+
 //***************************************************************************
 QString Kwave::urlScheme()
 {
